@@ -22,6 +22,7 @@ import (
 	"github.com/open-policy-agent/opa/v1/topdown"
 
 	rbundle "github.com/styrainc/regal/bundle"
+	"github.com/styrainc/regal/internal/cache"
 	rio "github.com/styrainc/regal/internal/io"
 	regalmetrics "github.com/styrainc/regal/internal/metrics"
 	"github.com/styrainc/regal/internal/update"
@@ -117,8 +118,8 @@ func init() {
 			errorsFound := 0
 			warningsFound := 0
 
-			for _, violation := range rep.Violations {
-				switch violation.Level {
+			for i := range rep.Violations {
+				switch rep.Violations[i].Level {
 				case "error":
 					errorsFound++
 				case "warning":
@@ -215,11 +216,11 @@ func lint(args []string, params *lintCommandParams) (report.Report, error) {
 		}
 	}
 
-	var regalDir *os.File
-
-	var customRulesDir string
-
-	var configSearchPath string
+	var (
+		regalDir         *os.File
+		customRulesDir   string
+		configSearchPath string
+	)
 
 	m := metrics.New()
 	if params.metrics {
@@ -248,8 +249,7 @@ func lint(args []string, params *lintCommandParams) (report.Report, error) {
 		m.Timer(regalmetrics.RegalConfigSearch).Stop()
 	}
 
-	regal := linter.NewEmptyLinter().
-		WithAddedBundle(&rbundle.LoadedBundle).
+	regal := linter.NewLinter().
 		WithDisableAll(params.disableAll).
 		WithDisabledCategories(params.disableCategory.v...).
 		WithDisabledRules(params.disable.v...).
@@ -257,7 +257,8 @@ func lint(args []string, params *lintCommandParams) (report.Report, error) {
 		WithEnabledCategories(params.enableCategory.v...).
 		WithEnabledRules(params.enable.v...).
 		WithDebugMode(params.debug).
-		WithInputPaths(args)
+		WithInputPaths(args).
+		WithBaseCache(cache.NewBaseCache())
 
 	if params.enablePrint {
 		regal = regal.WithPrintHook(topdown.NewPrintHook(os.Stderr))
@@ -328,6 +329,11 @@ func lint(args []string, params *lintCommandParams) (report.Report, error) {
 
 	go updateCheckAndWarn(params, &rbundle.LoadedBundle, &userConfig)
 
+	regal, err = regal.Prepare(ctx)
+	if err != nil {
+		return report.Report{}, fmt.Errorf("failed to prepare for linting: %w", err)
+	}
+
 	result, err := regal.Lint(ctx)
 	if err != nil {
 		return report.Report{}, formatError(params.format, fmt.Errorf("error(s) encountered while linting: %w", err))
@@ -405,7 +411,7 @@ func formatError(format string, err error) error {
 	// currently, JSON and SARIF will get the same generic JSON error format
 	switch format {
 	case formatJSON, formatSarif:
-		bs, err := json.MarshalIndent(map[string]interface{}{
+		bs, err := json.MarshalIndent(map[string]any{
 			"errors": []string{err.Error()},
 		}, "", "  ")
 		if err != nil {
