@@ -6,12 +6,13 @@ import (
 	"log"
 	"os"
 
-	"github.com/anderseknert/roast/pkg/encoding"
 	"github.com/spf13/cobra"
 
-	"github.com/open-policy-agent/opa/ast"
+	"github.com/open-policy-agent/opa/v1/util"
 
 	rp "github.com/styrainc/regal/internal/parse"
+
+	"github.com/styrainc/roast/pkg/encoding"
 )
 
 func init() {
@@ -51,9 +52,9 @@ func parse(args []string) error {
 		return err
 	}
 
-	content := string(bs)
+	content := util.ByteSliceToString(bs)
 
-	module, err := ast.ParseModuleWithOpts(filename, content, rp.ParserOptions())
+	module, err := rp.ModuleUnknownVersionWithOpts(filename, content, rp.ParserOptions())
 	if err != nil {
 		return err
 	}
@@ -63,12 +64,12 @@ func parse(args []string) error {
 		return err
 	}
 
-	bs, err = encoding.JSON().MarshalIndent(enhancedAST, "", "  ")
+	output, err := encoding.JSON().MarshalIndent(enhancedAST, "", "  ")
 	if err != nil {
 		return err
 	}
 
-	_, err = os.Stdout.Write(bs)
+	_, err = os.Stdout.Write(output)
 
 	return err
 }
