@@ -74,9 +74,9 @@ func (f loaderFilter) Apply(abspath string, info os.FileInfo, depth int) bool {
 	})
 }
 
-var testParams = newTestCommandParams() //nolint: gochecknoglobals
+var testParams = newTestCommandParams()
 
-var testCommand = &cobra.Command{ //nolint: gochecknoglobals
+var testCommand = &cobra.Command{
 	Hidden: true,
 	Use:    "test <path> [path [...]]",
 	Short:  "Execute Rego test cases for Regal",
@@ -331,6 +331,8 @@ func runTests(ctx context.Context, txn storage.Transaction, runner *tester.Runne
 				exitCode = 2
 			}
 
+			tr.Trace = nil
+
 			if tr.Skip && exitCode == 0 && testParams.skipExitZero {
 				// there is a skipped test, adding the flag -z exits 0 if there are no failures
 				exitCode = 0
