@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"path/filepath"
 	"time"
 
 	"github.com/styrainc/regal/pkg/config"
@@ -15,20 +16,31 @@ type configFileParams interface {
 	getConfigFile() string
 }
 
-func readUserConfig(params configFileParams, regalDir *os.File) (userConfig *os.File, err error) {
+func readUserConfig(params configFileParams, searchPath string) (userConfig *os.File, err error) {
 	if cfgFile := params.getConfigFile(); cfgFile != "" {
 		userConfig, err = os.Open(cfgFile)
 		if err != nil {
 			return nil, fmt.Errorf("failed to open config file %w", err)
 		}
 	} else {
-		searchPath, _ := os.Getwd()
-		if regalDir != nil {
-			searchPath = regalDir.Name()
+		if searchPath == "" {
+			searchPath, _ = os.Getwd()
 		}
 
-		if searchPath != "" {
-			userConfig, err = config.FindConfig(searchPath)
+		userConfig, err = config.FindConfig(searchPath)
+	}
+
+	// if there is no config found, attempt to load the user's global config if
+	// it exists
+	if err != nil {
+		globalConfigDir := config.GlobalConfigDir(false)
+		if globalConfigDir != "" {
+			globalConfigFile := filepath.Join(globalConfigDir, "config.yaml")
+
+			userConfig, err = os.Open(globalConfigFile)
+			if err != nil {
+				return nil, fmt.Errorf("failed to open global config file %w", err)
+			}
 		}
 	}
 
