@@ -22,6 +22,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/tester"
 
+	"github.com/styrainc/regal/internal/mode"
 	"github.com/styrainc/regal/internal/testutil"
 	"github.com/styrainc/regal/pkg/config"
 	"github.com/styrainc/regal/pkg/report"
@@ -111,6 +112,51 @@ func TestLintEmptyDir(t *testing.T) {
 	}
 }
 
+func TestLintFileFromStdin(t *testing.T) {
+	t.Parallel()
+
+	stdout, stderr := bytes.Buffer{}, bytes.Buffer{}
+
+	cmd := exec.Command(binary(), "lint", "-f", "json", "-")
+	cmd.Stdin = strings.NewReader("package p\n\nallow =  true")
+	cmd.Stdout = &stdout
+	cmd.Stderr = &stderr
+
+	if err := cmd.Run(); err == nil {
+		t.Fatal("expected error, got nil")
+	}
+
+	if exp, act := "", stderr.String(); exp != act {
+		t.Errorf("expected stderr %q, got %q", exp, act)
+	}
+
+	var rep report.Report
+	if err := json.Unmarshal(stdout.Bytes(), &rep); err != nil {
+		t.Fatalf("expected JSON response, got %v", stdout.String())
+	}
+
+	if rep.Summary.NumViolations != 2 {
+		t.Errorf("epected 2 violations, got %d", rep.Summary.NumViolations)
+	}
+
+	violations := make([]string, 0, len(rep.Violations))
+	for _, violation := range rep.Violations {
+		violations = append(violations, violation.Title)
+	}
+
+	slices.Sort(violations)
+
+	expected := []string{"opa-fmt", "use-assignment-operator"}
+
+	if !slices.Equal(violations, expected) {
+		t.Errorf("expected violations %v, got %v", expected, violations)
+	}
+
+	if exp, act := 3, cmd.ProcessState.ExitCode(); exp != act {
+		t.Errorf("expected exit code %d, got %d", exp, act)
+	}
+}
+
 func TestLintNonExistentDir(t *testing.T) {
 	if runtime.GOOS == "windows" {
 		t.Skip("skipping on Windows as the error message is different")
@@ -136,10 +182,11 @@ func TestLintNonExistentDir(t *testing.T) {
 	}
 }
 
-// NOTE(ae): this test *will fail* when run via "go test -e2e" and a normal development binary is used for the test.
-// This is because proposing fixes is only enabled when regal is built with the "regal_standalone" build tag. I spent
-// way more time on chasing that down than I would have wanted, so leaving this here for future me and others.
 func TestLintProposeToRunFix(t *testing.T) {
+	if !mode.Standalone {
+		t.Skip("test requires regal to be built with the 'regal_standalone' build tag")
+	}
+
 	t.Parallel()
 	stdout, stderr := bytes.Buffer{}, bytes.Buffer{}
 
@@ -530,7 +577,7 @@ func TestLintAggregateIgnoreDirective(t *testing.T) {
 	}
 
 	if rep.Summary.NumViolations != 2 {
-		t.Errorf("expected 2 violations, got %d", rep.Summary.NumViolations)
+		t.Fatalf("expected 2 violations, got %d", rep.Summary.NumViolations)
 	}
 
 	if rep.Summary.NumViolations == 0 {
@@ -1000,8 +1047,7 @@ allow := true
 func TestFixWithConflicts(t *testing.T) {
 	t.Parallel()
 
-	stdout := bytes.Buffer{}
-	stderr := bytes.Buffer{}
+	stdout, stderr := bytes.Buffer{}, bytes.Buffer{}
 
 	initialState := map[string]string{
 		".regal/config.yaml": "", // needed to find the root in the right place
@@ -1067,8 +1113,7 @@ Cannot move multiple files to: bar/bar.rego
 func TestFixWithConflictRenaming(t *testing.T) {
 	t.Parallel()
 
-	stdout := bytes.Buffer{}
-	stderr := bytes.Buffer{}
+	stdout, stderr := bytes.Buffer{}, bytes.Buffer{}
 
 	initialState := map[string]string{
 		".regal/config.yaml": "", // needed to find the root in the right place
@@ -1247,8 +1292,7 @@ rules:
 func TestLintAnnotationCustomAttributeMultipleItems(t *testing.T) {
 	t.Parallel()
 
-	stdout := bytes.Buffer{}
-	stderr := bytes.Buffer{}
+	stdout, stderr := bytes.Buffer{}, bytes.Buffer{}
 	cwd := testutil.Must(os.Getwd())(t)
 
 	err := regal(&stdout, &stderr)(
