@@ -87,15 +87,7 @@ func (c *Cache) Refresh() ([]string, error) {
 
 	// remove any bundles that are no longer present on disk
 	for root := range c.bundles {
-		found := false
-
-		for _, foundRoot := range foundBundleRoots {
-			if root == foundRoot {
-				found = true
-
-				break
-			}
-		}
+		found := slices.Contains(foundBundleRoots, root)
 
 		if !found {
 			delete(c.bundles, root)
@@ -123,7 +115,7 @@ func (c *Cache) Get(root string) (bundle.Bundle, bool) {
 
 // All returns all the bundles in the cache.
 func (c *Cache) All() map[string]bundle.Bundle {
-	bundles := make(map[string]bundle.Bundle)
+	bundles := make(map[string]bundle.Bundle, len(c.bundles))
 
 	for root, cacheBundle := range c.bundles {
 		bundles[root] = cacheBundle.bundle
