@@ -3,8 +3,8 @@ package lsp
 import (
 	"fmt"
 
-	"github.com/open-policy-agent/opa/ast"
-	"github.com/open-policy-agent/opa/types"
+	"github.com/open-policy-agent/opa/v1/ast"
+	"github.com/open-policy-agent/opa/v1/types"
 
 	"github.com/styrainc/regal/internal/lsp/rego"
 	types2 "github.com/styrainc/regal/internal/lsp/types"
