@@ -1,4 +1,4 @@
-//nolint:nilerr,nilnil,gochecknoglobals
+//nolint:nilerr,nilnil
 package lsp
 
 import (
@@ -20,12 +20,14 @@ import (
 	"gopkg.in/yaml.v3"
 
 	"github.com/open-policy-agent/opa/v1/ast"
+	"github.com/open-policy-agent/opa/v1/ast/oracle"
 	"github.com/open-policy-agent/opa/v1/format"
 	"github.com/open-policy-agent/opa/v1/storage"
 	outil "github.com/open-policy-agent/opa/v1/util"
 
 	rbundle "github.com/styrainc/regal/bundle"
 	"github.com/styrainc/regal/internal/capabilities"
+	"github.com/styrainc/regal/internal/compile"
 	rio "github.com/styrainc/regal/internal/io"
 	"github.com/styrainc/regal/internal/lsp/bundles"
 	"github.com/styrainc/regal/internal/lsp/cache"
@@ -37,7 +39,6 @@ import (
 	"github.com/styrainc/regal/internal/lsp/handler"
 	"github.com/styrainc/regal/internal/lsp/hover"
 	"github.com/styrainc/regal/internal/lsp/log"
-	"github.com/styrainc/regal/internal/lsp/opa/oracle"
 	"github.com/styrainc/regal/internal/lsp/rego"
 	"github.com/styrainc/regal/internal/lsp/types"
 	"github.com/styrainc/regal/internal/lsp/uri"
@@ -101,32 +102,6 @@ type LanguageServerOptions struct {
 	WorkspaceDiagnosticsPoll time.Duration
 }
 
-func NewLanguageServer(ctx context.Context, opts *LanguageServerOptions) *LanguageServer {
-	c := cache.NewCache()
-	store := NewRegalStore()
-
-	ls := &LanguageServer{
-		cache:                       c,
-		regoStore:                   store,
-		logWriter:                   opts.LogWriter,
-		logLevel:                    opts.LogLevel,
-		lintFileJobs:                make(chan lintFileJob, 10),
-		lintWorkspaceJobs:           make(chan lintWorkspaceJob, 10),
-		builtinsPositionJobs:        make(chan lintFileJob, 10),
-		commandRequest:              make(chan types.ExecuteCommandParams, 10),
-		templateFileJobs:            make(chan lintFileJob, 10),
-		completionsManager:          completions.NewDefaultManager(ctx, c, store),
-		webServer:                   web.NewServer(c, opts.LogWriter, opts.LogLevel),
-		loadedBuiltins:              concurrent.MapOf(make(map[string]map[string]*ast.Builtin)),
-		workspaceDiagnosticsPoll:    opts.WorkspaceDiagnosticsPoll,
-		loadedConfigAllRegoVersions: concurrent.MapOf(make(map[string]ast.RegoVersion)),
-	}
-
-	ls.configWatcher = lsconfig.NewWatcher(&lsconfig.WatcherOpts{LogFunc: ls.logf})
-
-	return ls
-}
-
 type LanguageServer struct {
 	logWriter io.Writer
 	logLevel  log.Level
@@ -181,6 +156,32 @@ type lintWorkspaceJob struct {
 	AggregateReportOnly bool
 }
 
+func NewLanguageServer(ctx context.Context, opts *LanguageServerOptions) *LanguageServer {
+	c := cache.NewCache()
+	store := NewRegalStore()
+
+	ls := &LanguageServer{
+		cache:                       c,
+		regoStore:                   store,
+		logWriter:                   opts.LogWriter,
+		logLevel:                    opts.LogLevel,
+		lintFileJobs:                make(chan lintFileJob, 10),
+		lintWorkspaceJobs:           make(chan lintWorkspaceJob, 10),
+		builtinsPositionJobs:        make(chan lintFileJob, 10),
+		commandRequest:              make(chan types.ExecuteCommandParams, 10),
+		templateFileJobs:            make(chan lintFileJob, 10),
+		completionsManager:          completions.NewDefaultManager(ctx, c, store),
+		webServer:                   web.NewServer(c, opts.LogWriter, opts.LogLevel),
+		loadedBuiltins:              concurrent.MapOf(make(map[string]map[string]*ast.Builtin)),
+		workspaceDiagnosticsPoll:    opts.WorkspaceDiagnosticsPoll,
+		loadedConfigAllRegoVersions: concurrent.MapOf(make(map[string]ast.RegoVersion)),
+	}
+
+	ls.configWatcher = lsconfig.NewWatcher(&lsconfig.WatcherOpts{LogFunc: ls.logf})
+
+	return ls
+}
+
 //nolint:wrapcheck
 func (l *LanguageServer) Handle(ctx context.Context, _ *jsonrpc2.Conn, req *jsonrpc2.Request) (any, error) {
 	l.logf(log.LevelDebug, "received request: %s", req.Method)
@@ -478,59 +479,6 @@ func (l *LanguageServer) StartHoverWorker(ctx context.Context) {
 	}
 }
 
-func (l *LanguageServer) getLoadedConfig() *config.Config {
-	l.loadedConfigLock.RLock()
-	defer l.loadedConfigLock.RUnlock()
-
-	return l.loadedConfig
-}
-
-func (l *LanguageServer) getEnabledNonAggregateRules() []string {
-	l.loadedConfigLock.RLock()
-	defer l.loadedConfigLock.RUnlock()
-
-	return l.loadedConfigEnabledNonAggregateRules
-}
-
-func (l *LanguageServer) getEnabledAggregateRules() []string {
-	l.loadedConfigLock.RLock()
-	defer l.loadedConfigLock.RUnlock()
-
-	return l.loadedConfigEnabledAggregateRules
-}
-
-// loadEnabledRulesFromConfig is used to cache the enabled rules for the current
-// config. These take some time to compute and only change when config changes,
-// so we can store them on the server to speed up diagnostic runs.
-func (l *LanguageServer) loadEnabledRulesFromConfig(ctx context.Context, cfg config.Config) error {
-	lint := linter.NewLinter().WithUserConfig(cfg)
-
-	enabledRules, err := lint.DetermineEnabledRules(ctx)
-	if err != nil {
-		return fmt.Errorf("failed to determine enabled rules: %w", err)
-	}
-
-	enabledAggregateRules, err := lint.DetermineEnabledAggregateRules(ctx)
-	if err != nil {
-		return fmt.Errorf("failed to determine enabled aggregate rules: %w", err)
-	}
-
-	l.loadedConfigLock.Lock()
-	defer l.loadedConfigLock.Unlock()
-
-	l.loadedConfigEnabledNonAggregateRules = []string{}
-
-	for _, r := range enabledRules {
-		if !slices.Contains(enabledAggregateRules, r) {
-			l.loadedConfigEnabledNonAggregateRules = append(l.loadedConfigEnabledNonAggregateRules, r)
-		}
-	}
-
-	l.loadedConfigEnabledAggregateRules = enabledAggregateRules
-
-	return nil
-}
-
 func (l *LanguageServer) StartConfigWorker(ctx context.Context) {
 	if err := l.configWatcher.Start(ctx); err != nil {
 		l.logf(log.LevelMessage, "failed to start config watcher: %s", err)
@@ -749,17 +697,10 @@ func (l *LanguageServer) StartCommandWorker(ctx context.Context) { //nolint:main
 					args,
 				)
 			case "regal.fix.directory-package-mismatch":
-				fileURL, ok := params.Arguments[0].(string)
-				if !ok {
-					l.logf(log.LevelMessage, "expected first argument to be a string, got %T", params.Arguments[0])
-
-					break
-				}
-
 				params, err := l.fixRenameParams(
 					"Rename file to match package path",
 					&fixes.DirectoryPackageMismatch{},
-					fileURL,
+					args.Target,
 				)
 				if err != nil {
 					l.logf(log.LevelMessage, "failed to fix directory package mismatch: %s", err)
@@ -1081,6 +1022,59 @@ func (l *LanguageServer) StartWebServer(ctx context.Context) {
 	l.webServer.Start(ctx)
 }
 
+func (l *LanguageServer) getLoadedConfig() *config.Config {
+	l.loadedConfigLock.RLock()
+	defer l.loadedConfigLock.RUnlock()
+
+	return l.loadedConfig
+}
+
+func (l *LanguageServer) getEnabledNonAggregateRules() []string {
+	l.loadedConfigLock.RLock()
+	defer l.loadedConfigLock.RUnlock()
+
+	return l.loadedConfigEnabledNonAggregateRules
+}
+
+func (l *LanguageServer) getEnabledAggregateRules() []string {
+	l.loadedConfigLock.RLock()
+	defer l.loadedConfigLock.RUnlock()
+
+	return l.loadedConfigEnabledAggregateRules
+}
+
+// loadEnabledRulesFromConfig is used to cache the enabled rules for the current
+// config. These take some time to compute and only change when config changes,
+// so we can store them on the server to speed up diagnostic runs.
+func (l *LanguageServer) loadEnabledRulesFromConfig(ctx context.Context, cfg config.Config) error {
+	lint := linter.NewLinter().WithUserConfig(cfg)
+
+	enabledRules, err := lint.DetermineEnabledRules(ctx)
+	if err != nil {
+		return fmt.Errorf("failed to determine enabled rules: %w", err)
+	}
+
+	enabledAggregateRules, err := lint.DetermineEnabledAggregateRules(ctx)
+	if err != nil {
+		return fmt.Errorf("failed to determine enabled aggregate rules: %w", err)
+	}
+
+	l.loadedConfigLock.Lock()
+	defer l.loadedConfigLock.Unlock()
+
+	l.loadedConfigEnabledNonAggregateRules = []string{}
+
+	for _, r := range enabledRules {
+		if !slices.Contains(enabledAggregateRules, r) {
+			l.loadedConfigEnabledNonAggregateRules = append(l.loadedConfigEnabledNonAggregateRules, r)
+		}
+	}
+
+	l.loadedConfigEnabledAggregateRules = enabledAggregateRules
+
+	return nil
+}
+
 func (l *LanguageServer) templateContentsForFile(fileURI string) (string, error) {
 	// this function should not be called with files in the root, but if it is,
 	// then it is an error to prevent unwanted behavior.
@@ -1236,7 +1230,7 @@ func (l *LanguageServer) fixEditParams(
 func (l *LanguageServer) fixRenameParams(
 	label string,
 	fix fixes.Fix,
-	fileURL string,
+	fileURI string,
 ) (types.ApplyWorkspaceAnyEditParams, error) {
 	var result types.ApplyWorkspaceAnyEditParams
 
@@ -1255,7 +1249,7 @@ func (l *LanguageServer) fixRenameParams(
 		{
 			Title: fix.Name(),
 			Location: report.Location{
-				File: uri.ToPath(l.clientIdentifier, fileURL),
+				File: uri.ToPath(l.clientIdentifier, fileURI),
 			},
 		},
 	}
@@ -1303,6 +1297,14 @@ func (l *LanguageServer) fixRenameParams(
 	oldURI := uri.FromPath(l.clientIdentifier, oldFile)
 	newURI := uri.FromPath(l.clientIdentifier, fixedFile)
 
+	// is the newURI still in the root?
+	if !strings.HasPrefix(newURI, l.workspaceRootURI) {
+		return types.ApplyWorkspaceAnyEditParams{
+			Label: label,
+			Edit:  types.WorkspaceAnyEdit{},
+		}, errors.New("cannot move file out of workspace root, consider using a workspace config or manually setting roots")
+	}
+
 	// are there old dirs?
 	dirs, err := util.DirCleanUpPaths(
 		uri.ToPath(l.clientIdentifier, oldURI),
@@ -1590,7 +1592,11 @@ func (l *LanguageServer) handleTextDocumentCodeAction(params types.CodeActionPar
 			})
 		}
 
-		if l.clientIdentifier == clients.IdentifierVSCode {
+		if diag.CodeDescription == nil {
+			l.logf(log.LevelMessage, "missing code description and href for %q", diag.Code)
+		}
+
+		if l.clientIdentifier == clients.IdentifierVSCode && diag.CodeDescription != nil {
 			// always show the docs link
 			txt := "Show documentation for " + diag.Code
 			actions = append(actions, types.CodeAction{
@@ -1678,7 +1684,7 @@ func (l *LanguageServer) handleTextDocumentCodeLens(ctx context.Context, params
 			return noCodeLenses, nil
 		}
 
-		if len(strings.Split(contents, "\n")) != lastSuccessfullyParsedLineCount {
+		if strings.Count(contents, "\n")+1 != lastSuccessfullyParsedLineCount {
 			return noCodeLenses, nil
 		}
 	}
@@ -1819,6 +1825,8 @@ func (l *LanguageServer) handleTextDocumentDefinition(params types.DefinitionPar
 		Buffer:   outil.StringToByteSlice(contents),
 	}
 
+	orc := orc.WithCompiler(compile.NewCompilerWithRegalBuiltins())
+
 	definition, err := orc.FindDefinition(query)
 	if err != nil {
 		if errors.Is(err, oracle.ErrNoDefinitionFound) || errors.Is(err, oracle.ErrNoMatchFound) {
@@ -2398,8 +2406,12 @@ func (l *LanguageServer) handleInitialize(ctx context.Context, params types.Init
 			l.configWatcher.Watch(configFile.Name())
 		case globalConfigDir != "":
 			globalConfigFile := filepath.Join(globalConfigDir, "config.yaml")
-			l.logf(log.LevelMessage, "using global config file: %s", globalConfigFile)
-			l.configWatcher.Watch(globalConfigFile)
+			// the file might not exist and we only want to log we're using the
+			// global file if it does.
+			if _, err = os.Stat(globalConfigFile); err == nil {
+				l.logf(log.LevelMessage, "using global config file: %s", globalConfigFile)
+				l.configWatcher.Watch(globalConfigFile)
+			}
 		default:
 			l.logf(log.LevelMessage, "no config file found for workspace: %s", err)
 		}
