@@ -42,7 +42,7 @@ import rego.v1
 	messages := createMessageChannels(files)
 	clientHandler := createClientHandler(t, logger, messages)
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(t.Context())
 	defer cancel()
 
 	_, connClient := createAndInitServer(t, ctx, logger, tempDir, clientHandler)
@@ -169,7 +169,7 @@ package bar
 	logger := newTestLogger(t)
 	clientHandler := createClientHandler(t, logger, messages)
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(t.Context())
 	defer cancel()
 
 	tempDir := testutil.TempDirectoryOf(t, files)
@@ -219,7 +219,7 @@ import data.quz
 		".regal/config.yaml": ``,
 	}
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(t.Context())
 	defer cancel()
 
 	tempDir := testutil.TempDirectoryOf(t, files)
@@ -259,8 +259,8 @@ import data.quz
 			if aggregateData, ok := entry["aggregate_data"].(map[string]any); ok {
 				if importsList, ok := aggregateData["imports"].([]any); ok {
 					for _, imp := range importsList {
-						if impMap, ok := imp.(map[string]any); ok {
-							if pathList, ok := impMap["path"].([]any); ok {
+						if item, ok := imp.([]any); ok {
+							if pathList, ok := item[0].([]any); ok {
 								pathParts := []string{}
 
 								for _, p := range pathList {
@@ -355,7 +355,7 @@ import rego.v1
 	clientHandler := createClientHandler(t, logger, messages)
 
 	// set up the server and client connections
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(t.Context())
 	defer cancel()
 
 	_, connClient := createAndInitServer(t, ctx, logger, tempDir, clientHandler)
