@@ -1,8 +1,10 @@
 package lsp
 
 import (
-	"context"
 	"fmt"
+	"os"
+	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/styrainc/regal/internal/lsp/cache"
@@ -21,7 +23,7 @@ func TestLanguageServerFixRenameParams(t *testing.T) {
 
 	testutil.MustMkdirAll(t, tmpDir, "workspace", "foo", "bar")
 
-	ctx := context.Background()
+	ctx := t.Context()
 
 	logger := newTestLogger(t)
 
@@ -33,12 +35,13 @@ func TestLanguageServerFixRenameParams(t *testing.T) {
 	c := cache.NewCache()
 	f := &fixes.DirectoryPackageMismatch{}
 
-	fileURI := fmt.Sprintf("file://%s/workspace/foo/bar/policy.rego", tmpDir)
+	rootURI := fmt.Sprintf("file://%s/workspace", tmpDir)
+	fileURI := rootURI + "/foo/bar/policy.rego"
 
 	c.SetFileContents(fileURI, "package authz.main.rules")
 
 	ls.clientIdentifier = clients.IdentifierVSCode
-	ls.workspaceRootURI = fmt.Sprintf("file://%s/workspace", tmpDir)
+	ls.workspaceRootURI = rootURI
 	ls.cache = c
 	ls.loadedConfig = &config.Config{
 		Rules: map[string]config.Category{
@@ -83,7 +86,7 @@ func TestLanguageServerFixRenameParams(t *testing.T) {
 func TestLanguageServerFixRenameParamsWithConflict(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := t.Context()
 	logger := newTestLogger(t)
 	tmpDir := t.TempDir()
 
@@ -97,7 +100,8 @@ func TestLanguageServerFixRenameParamsWithConflict(t *testing.T) {
 	c := cache.NewCache()
 	f := &fixes.DirectoryPackageMismatch{}
 
-	fileURI := fmt.Sprintf("file://%s/workspace/foo/bar/policy.rego", tmpDir)
+	rootURI := fmt.Sprintf("file://%s/workspace", tmpDir)
+	fileURI := rootURI + "/foo/bar/policy.rego"
 
 	c.SetFileContents(fileURI, "package authz.main.rules")
 
@@ -107,7 +111,7 @@ func TestLanguageServerFixRenameParamsWithConflict(t *testing.T) {
 	c.SetFileContents(conflictingFileURI, "package authz.main.rules")
 
 	ls.clientIdentifier = clients.IdentifierVSCode
-	ls.workspaceRootURI = fmt.Sprintf("file://%s/workspace", tmpDir)
+	ls.workspaceRootURI = rootURI
 	ls.cache = c
 	ls.loadedConfig = &config.Config{
 		Rules: map[string]config.Category{
@@ -176,3 +180,60 @@ func TestLanguageServerFixRenameParamsWithConflict(t *testing.T) {
 		t.Fatalf("expected delete URI to be %s, got %s", expectedDeletedURI2, deleteChange2.URI)
 	}
 }
+
+func TestLanguageServerFixRenameParamsWhenTargetOutsideRoot(t *testing.T) {
+	t.Parallel()
+
+	ctx := t.Context()
+	logger := newTestLogger(t)
+	tmpDir := t.TempDir()
+
+	testutil.MustMkdirAll(t, tmpDir, "workspace", "foo", "bar")
+
+	// this will have regal find a root in the parent dir, which means the file
+	// is moved relative to a dir above the workspace.
+	err := os.WriteFile(filepath.Join(tmpDir, ".regal.yaml"), []byte{}, 0o600)
+	if err != nil {
+		t.Fatalf("failed to write config file: %s", err)
+	}
+
+	ls := NewLanguageServer(
+		ctx,
+		&LanguageServerOptions{LogWriter: logger, LogLevel: log.LevelDebug},
+	)
+
+	c := cache.NewCache()
+	f := &fixes.DirectoryPackageMismatch{}
+
+	// the root where the client stated the workspace is
+	rootURI := fmt.Sprintf("file://%s/workspace/", tmpDir)
+	fileURI := rootURI + "foo/bar/policy.rego"
+
+	c.SetFileContents(fileURI, "package authz.main.rules")
+
+	ls.clientIdentifier = clients.IdentifierVSCode
+	// this is what would be set if a config file were in the parent instead
+	ls.workspaceRootURI = rootURI
+	ls.cache = c
+	ls.loadedConfig = &config.Config{
+		Rules: map[string]config.Category{
+			"idiomatic": {
+				"directory-package-mismatch": config.Rule{
+					Level: "ignore",
+					Extra: map[string]any{
+						"exclude-test-suffix": true,
+					},
+				},
+			},
+		},
+	}
+
+	_, err = ls.fixRenameParams("fix my file!", f, fileURI)
+	if err == nil {
+		t.Fatalf("expected error, got nil")
+	}
+
+	if !strings.Contains(err.Error(), "cannot move file out of workspace root") {
+		t.Fatalf("expected error to contain 'cannot move file out of workspace root', got %s", err)
+	}
+}
