@@ -1,7 +1,7 @@
 package metrics
 
 import (
-	"github.com/open-policy-agent/opa/profiler"
+	"github.com/open-policy-agent/opa/v1/profiler"
 
 	"github.com/styrainc/regal/pkg/report"
 )
@@ -13,7 +13,6 @@ const (
 	RegalFilterIgnoredModules = "regal_filter_ignored_modules"
 	RegalInputParse           = "regal_input_parse"
 	RegalLint                 = "regal_lint_total"
-	RegalLintGo               = "regal_lint_go"
 	RegalLintRego             = "regal_lint_rego"
 	RegalLintRegoAggregate    = "regal_lint_rego_aggregate"
 )
