@@ -2,7 +2,6 @@ package linter
 
 import (
 	"bytes"
-	"context"
 	"embed"
 	"path/filepath"
 	"slices"
@@ -14,6 +13,8 @@ import (
 	"github.com/open-policy-agent/opa/v1/ast"
 	"github.com/open-policy-agent/opa/v1/topdown"
 
+	"github.com/styrainc/regal/bundle"
+	"github.com/styrainc/regal/internal/cache"
 	"github.com/styrainc/regal/internal/parse"
 	"github.com/styrainc/regal/internal/test"
 	"github.com/styrainc/regal/internal/testutil"
@@ -36,7 +37,7 @@ camelCase if {
 
 	linter := NewLinter().WithEnableAll(true).WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 2 {
 		t.Fatalf("expected 2 violations, got %d", len(result.Violations))
@@ -94,7 +95,7 @@ r := input.foo[_]
 
 	linter := NewLinter().WithUserConfig(userConfig).WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 1 {
 		t.Fatalf("expected 1 violation, got %d - violations: %v", len(result.Violations), result.Violations)
@@ -279,7 +280,7 @@ or := 1
 				linter = linter.WithUserConfig(*tc.userConfig)
 			}
 
-			result := testutil.Must(linter.Lint(context.Background()))(t)
+			result := testutil.Must(linter.Lint(t.Context()))(t)
 
 			if len(result.Violations) != len(tc.expViolations) {
 				t.Fatalf("expected %d violation, got %d: %v",
@@ -315,7 +316,7 @@ func TestLintWithCustomRule(t *testing.T) {
 		WithCustomRules([]string{filepath.Join("testdata", "custom.rego")}).
 		WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 1 {
 		t.Fatalf("expected 1 violation, got %d", len(result.Violations))
@@ -336,7 +337,7 @@ func TestLintWithErrorInEnable(t *testing.T) {
 		WithEnabledRules("foo").
 		WithInputModules(&input)
 
-	_, err := linter.Lint(context.Background())
+	_, err := linter.Lint(t.Context())
 	if err == nil {
 		t.Fatal("expected error, got nil")
 	}
@@ -358,7 +359,7 @@ func TestLintWithCustomEmbeddedRules(t *testing.T) {
 		WithCustomRulesFromFS(testLintWithCustomEmbeddedRulesFS, "testdata").
 		WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 1 {
 		t.Fatalf("expected 1 violation, got %d", len(result.Violations))
@@ -383,7 +384,7 @@ func TestLintWithCustomRuleAndCustomConfig(t *testing.T) {
 		WithCustomRules([]string{filepath.Join("testdata", "custom.rego")}).
 		WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 0 {
 		t.Fatalf("expected no violation, got %d", len(result.Violations))
@@ -481,7 +482,7 @@ func TestLintWithPrintHook(t *testing.T) {
 		WithPrintHook(topdown.NewPrintHook(&bb)).
 		WithInputModules(&input)
 
-	if _, err := linter.Lint(context.Background()); err != nil {
+	if _, err := linter.Lint(t.Context()); err != nil {
 		t.Fatal(err)
 	}
 
@@ -516,7 +517,7 @@ func TestLintWithAggregateRule(t *testing.T) {
 		WithEnabledRules("prefer-package-imports").
 		WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 1 {
 		t.Fatalf("expected one violation, got %d", len(result.Violations))
@@ -536,7 +537,7 @@ func TestLintWithAggregateRule(t *testing.T) {
 		t.Errorf("expected violation to be on column 3, got %d", violation.Location.Column)
 	}
 
-	if *violation.Location.Text != "\t\timport data.foo.allow" {
+	if *violation.Location.Text != "import data.foo.allow" {
 		t.Errorf("expected violation to be on 'import data.foo.allow', got %q", *violation.Location.Text)
 	}
 }
@@ -548,7 +549,7 @@ func TestEnabledRules(t *testing.T) {
 		WithDisableAll(true).
 		WithEnabledRules("opa-fmt", "no-whitespace-comment")
 
-	enabledRules, err := linter.DetermineEnabledRules(context.Background())
+	enabledRules, err := linter.DetermineEnabledRules(t.Context())
 	if err != nil {
 		t.Fatalf("expected no error, got %v", err)
 	}
@@ -590,12 +591,12 @@ rules:
 
 	linter := NewLinter().WithUserConfig(userConfig)
 
-	enabledRules, err := linter.DetermineEnabledRules(context.Background())
+	enabledRules, err := linter.DetermineEnabledRules(t.Context())
 	if err != nil {
 		t.Fatalf("expected no error, got %v", err)
 	}
 
-	enabledAggRules, err := linter.DetermineEnabledAggregateRules(context.Background())
+	enabledAggRules, err := linter.DetermineEnabledAggregateRules(t.Context())
 	if err != nil {
 		t.Fatalf("expected no error, got %v", err)
 	}
@@ -624,7 +625,7 @@ func TestEnabledAggregateRules(t *testing.T) {
 		WithDisableAll(true).
 		WithEnabledRules("opa-fmt", "unresolved-import", "use-assignment-operator")
 
-	enabledRules, err := linter.DetermineEnabledAggregateRules(context.Background())
+	enabledRules, err := linter.DetermineEnabledAggregateRules(t.Context())
 	if err != nil {
 		t.Fatalf("expected no error, got %v", err)
 	}
@@ -653,7 +654,7 @@ import data.foo.bar.unresolved
 		WithExportAggregates(true). // needed to be able to test the aggregates are set
 		WithInputModules(&input)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Aggregates) != 1 {
 		t.Fatalf("expected one aggregate, got %d", len(result.Aggregates))
@@ -691,7 +692,7 @@ import data.unresolved`,
 			WithExportAggregates(true).
 			WithInputModules(&input)
 
-		result := testutil.Must(linter.Lint(context.Background()))(t)
+		result := testutil.Must(linter.Lint(t.Context()))(t)
 
 		for k, aggs := range result.Aggregates {
 			allAggregates[k] = append(allAggregates[k], aggs...)
@@ -703,7 +704,7 @@ import data.unresolved`,
 		WithEnabledRules("unresolved-import").
 		WithAggregates(allAggregates)
 
-	result := testutil.Must(linter.Lint(context.Background()))(t)
+	result := testutil.Must(linter.Lint(t.Context()))(t)
 
 	if len(result.Violations) != 3 {
 		t.Fatalf("expected one violation, got %d", len(result.Violations))
@@ -726,51 +727,102 @@ import data.unresolved`,
 	}
 }
 
-// 1809032500 ns/op	3227205712 B/op	63995081 allocs/op
-// 1692214541 ns/op	3089440208 B/op	60822121 allocs/op main
-// 1654144083 ns/op	3044255536 B/op	60234057 allocs/op opa-fmt-remodel
+// 930767688 ns/op	2765064504 B/op	50859905 allocs/op    OPA v1.5.0
+// 948058583 ns/op	2826178208 B/op	51937635 allocs/op´   OPA v1.5.1
 // ...
 func BenchmarkRegalLintingItself(b *testing.B) {
+	conf, err := config.FromPath(filepath.Join("..", "..", ".regal", "config.yaml"))
+	if err != nil {
+		b.Fatal(err)
+	}
+
 	linter := NewLinter().
 		WithInputPaths([]string{"../../bundle"}).
-		WithEnableAll(true)
-
-	b.ResetTimer()
-	b.ReportAllocs()
-
-	var err error
+		WithBaseCache(cache.NewBaseCache()).
+		WithUserConfig(conf)
 
 	var rep report.Report
 
 	for range b.N {
-		rep, err = linter.Lint(context.Background())
+		rep, err = linter.Lint(b.Context())
 		if err != nil {
 			b.Fatal(err)
 		}
 	}
 
 	if len(rep.Violations) != 0 {
-		_ = rep.Violations
+		b.Fatalf("expected no violations, got %v", rep.Violations)
 	}
 }
 
-// 268203979 ns/op	501748262 B/op	 9724107 allocs/op
-// 258819136 ns/op	497016108 B/op	 9632445 allocs/op
+// 955670792 ns/op	3004937416 B/op	57408554 allocs/op
+// ...
+func BenchmarkRegalLintingItselfPrepareOnce(b *testing.B) {
+	conf, err := config.FromPath(filepath.Join("..", "..", ".regal", "config.yaml"))
+	if err != nil {
+		b.Fatal(err)
+	}
+
+	ctx := b.Context()
+	linter := NewLinter().
+		WithInputPaths([]string{"../../bundle"}).
+		WithBaseCache(cache.NewBaseCache()).
+		WithUserConfig(conf).
+		MustPrepare(ctx)
+
+	var rep report.Report
+
+	for range b.N {
+		rep, err = linter.Lint(ctx)
+		if err != nil {
+			b.Fatal(err)
+		}
+	}
+
+	if len(rep.Violations) != 0 {
+		b.Fatalf("expected no violations, got %v", rep.Violations)
+	}
+}
+
+// 6	 168875708 ns/op	455586606 B/op	 8537889 allocs/op
 // ...
 func BenchmarkRegalNoEnabledRules(b *testing.B) {
 	linter := NewLinter().
 		WithInputPaths([]string{"../../bundle"}).
+		WithBaseCache(cache.NewBaseCache()).
 		WithDisableAll(true)
 
-	b.ResetTimer()
-	b.ReportAllocs()
-
 	var err error
 
 	var rep report.Report
 
 	for range b.N {
-		rep, err = linter.Lint(context.Background())
+		rep, err = linter.Lint(b.Context())
+		if err != nil {
+			b.Fatal(err)
+		}
+	}
+
+	if len(rep.Violations) != 0 {
+		b.Fatalf("expected no violations, got %v", rep.Violations)
+	}
+}
+
+// 97546746 ns/op	401323023 B/op	 7427903 allocs/op
+// ...
+func BenchmarkRegalNoEnabledRulesPrepareOnce(b *testing.B) {
+	linter := NewLinter().
+		WithInputPaths([]string{"../../bundle"}).
+		WithBaseCache(cache.NewBaseCache()).
+		WithDisableAll(true).
+		MustPrepare(b.Context())
+
+	var err error
+
+	var rep report.Report
+
+	for range b.N {
+		rep, err = linter.Lint(b.Context())
 		if err != nil {
 			b.Fatal(err)
 		}
@@ -780,3 +832,51 @@ func BenchmarkRegalNoEnabledRules(b *testing.B) {
 		_ = rep.Violations
 	}
 }
+
+// Runs a separate benchmark for each rule in the bundle. Note that this will take *several* minutes to run,
+// meaning you do NOT want to do this more than occasionally. You may however find it helpful to use this with
+// a single, or handful of rules to get a better idea of how long they take to run, and relative to each other.
+// The reason why this is currently so slow is that we parse + compile everything for each rule, which is really
+// something we should fix: https://github.com/StyraInc/regal/issues/1394
+func BenchmarkEachRule(b *testing.B) {
+	conf, err := config.LoadConfigWithDefaultsFromBundle(&bundle.LoadedBundle, nil)
+	if err != nil {
+		b.Fatal(err)
+	}
+
+	ctx := b.Context()
+	linter := NewLinter().
+		WithInputPaths([]string{"../../bundle"}).
+		WithBaseCache(cache.NewBaseCache()).
+		WithDisableAll(true).
+		MustPrepare(ctx)
+
+	for _, category := range conf.Rules {
+		for ruleName := range category {
+			// Uncomment / modify this to benchmark specific rule(s) only
+			//
+			// if ruleName != "metasyntactic-variable" {
+			// 	continue
+			// }
+			b.Run(ruleName, func(b *testing.B) {
+				b.ResetTimer()
+				b.ReportAllocs()
+
+				var err error
+
+				var rep report.Report
+
+				for range b.N {
+					rep, err = linter.WithEnabledRules(ruleName).Lint(ctx)
+					if err != nil {
+						b.Fatal(err)
+					}
+				}
+
+				if len(rep.Violations) != 0 {
+					_ = rep.Violations
+				}
+			})
+		}
+	}
+}
